<?php
include_once '../Logic/config.php';

$stmt = DB->prepare("SELECT * FROM bus");
$stmt->execute();
$buses = $stmt->fetchAll(PDO::FETCH_ASSOC);

function editBusInfo($data, $busService) {
    // 初始化SQL语句的基础部分
    $sql = "UPDATE bus SET ";
    $params = [];
    $updates = [];

    // 遍历$data数组，只添加非空字段到SQL更新语句中
    foreach ($data as $key => $value) {
        if (!empty($value)) {
            $updates[] = "`$key` = ?";
            $params[] = $value;
        }
    }

    // 如果没有需要更新的数据，则直接返回
    if (empty($updates)) {
        return false;
    }

    // 将所有更新拼接到基础SQL语句后面
    $sql .= implode(', ', $updates);
    $sql .= " WHERE service = ?";
    $params[] = $busService;

    // 准备和执行SQL语句
    $stmt = DB->prepare($sql);
    return $stmt->execute($params);
}

function addBusInfo($busService, $busLine) {
    // 查询公交数据库
    $stmt = DB->prepare("SELECT * FROM bus WHERE service = ?");
    $stmt->execute([$busService]);
    $bus = $stmt->fetch(PDO::FETCH_ASSOC);
    if ($bus) {
        // 该路线已存在
        echo "<script>alert('Already has this bus line!');</script>";
        echo "<script>window.location.href = window.location.href;</script>";
        exit;
    }
    //在数据库中创建新公交路线
    $sql = "INSERT INTO bus(service, bus_path) VALUES (?, ?)";
    $stmt = DB->prepare($sql);
    return $stmt->execute([$busService, $busLine]);
}
function delBus($busService) {
    $sql = "DELETE FROM bus WHERE service = ?";
    $stmt = DB->prepare($sql);
    return $stmt->execute([$busService]);
}




if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // 处理表单提交的数据
    if ($_POST["formType"] == "editBusForm") {
        $busService = $_POST['busService'];
        $data = [
            'bus_path' => $_POST['busLine'],
            'service' => $_POST['serviceNum']
        ];

        editBusInfo($data, $busService);
//        echo "<script>window.location.href ='../Admin/bus_manage.php';</script>";
    } elseif ($_POST["formType"] == "addBusForm") {
        $busService = $_POST['busService'];
        $busLine = $_POST['busLine'];

        addBusInfo($busService, $busLine);
        echo "<script>window.location.href ='../Admin/bus_manage.php';</script>";
    }elseif ($_POST["formType"] == "delBusForm") {
        $busService = $_POST['busService'];

        delBus($busService);
        echo "<script>window.location.href ='../Admin/bus_manage.php';</script>";
    }
}

?>
    <!DOCTYPE html>
    <html lang="zh-CN">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>Bus Line Management</title>
        <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
        <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.3/css/all.min.css">
    </head>
<body class="bg-gray-100">
<div class="container mx-auto p-4">
    <table class="min-w-full max-w-4xl mx-auto border-collapse">
    <thead class="bg-gray-800 text-white">
    <tr class="border-b">
        <th class="px-4 py-2 text-left rounded-tl-lg">Bus line No.</th>
        <th class="px-4 py-2 text-left">Bus line Services</th>
        <th class="px-4 py-2 text-left rounded-tr-lg">Operations</th>
    </tr>
    </thead>
    <tbody>
        <?php foreach ($buses as $bus) { ?>
            <tr class="border-b">
                <td class="px-4 py-2"><?php echo htmlspecialchars($bus['service']) ?></td>
                <td class="px-4 py-2"><?php echo htmlspecialchars($bus['bus_path']) ?></td>
                <td class="px-4 py-2 text-center">
                    <!-- 编辑按钮 -->
                    <button class="edit-btn text-blue-500 hover:text-blue-700 mx-2"
                            data-id="<?php echo $bus['service'] ?>"
                            data-type="edit">
                        <i class="fas fa-edit"></i>
                    </button>
                    <!-- 删除按钮 -->
                    <form action="../Admin/bus_manage.php" method="post" class="inline-block">
                        <input type="hidden" name="busService"
                               value="<?php echo htmlspecialchars($bus['service']) ?>">
                        <input type="hidden" name="formType" value="delBusForm">
                        <button type="submit" class="text-red-500 hover:text-red-700 mx-2">
                            <i class="fas fa-trash-alt"></i>
                        </button>
                    </form>
                </td>
            </tr>
        <?php } ?>
        <!-- 增加按钮 -->
        <tr class="border-b">
            <td colspan="6" class="px-4 py-2 text-center">
                <button class="add-btn text-green-500 hover:text-green-700 mx-2" data-type="add">
                    <i class="fas fa-plus-square"></i>
                </button>
            </td>
        </tr>
    </tbody>
    </table>
</div>

<!-- 弹出框，初始时隐藏 -->
<div id="modal"
     class="hidden fixed inset-0 bg-gray-600 bg-opacity-50 overflow-y-auto h-full w-full flex items-center justify-center">
    <div class="bg-white p-10 rounded-lg shadow-lg max-w-2xl w-full mx-auto" id="modal-content">
        <!-- 弹出框内容 -->
    </div>
</div>

<div class="fixed bottom-0 right-0 p-4">
    <button onclick="window.location.reload()"
            class="px-4 py-2 bg-gray-800 text-white rounded-md shadow-md hover:bg-gray-900 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-opacity-50">
        <i class="fas fa-sync-alt mr-2"></i>
    </button>
</div>

<script>
    document.addEventListener("DOMContentLoaded", () => {
        const editButtons = document.querySelectorAll('.edit-btn');
        const addButtons = document.querySelectorAll('.add-btn');
        const modal = document.getElementById('modal');
        const modalContent = document.getElementById('modal-content');

        // 编辑按钮点击事件
        editButtons.forEach(button => {
            button.addEventListener('click', function () {
                // 获取当前行
                const currentRow = button.closest('tr');
                // 从当前行中获取数据
                const busService = this.getAttribute('data-id');

                modalContent.innerHTML = `
        <h2 class="text-lg font-bold mb-4">Edit Bus lines Info</h2>
        <form id="editBusForm" class="space-y-4" action="../Admin/bus_manage.php" method="post">
                <input type="hidden" name="busService" value="${busService}">
                <input type="hidden" name="formType" value="editBusForm">
            <div>
                <label class="block text-sm font-medium text-gray-700" for="busService">Bus Service Number</label>
                <input type="text" name="serviceNum" placeholder="${busService}" id="serviceNum" class="mt-1 block w-full px-3 py-2 bg-white border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-blue-500 focus:border-blue-500">
            </div>
            <div>
                <label class="block text-sm font-medium text-gray-700" for="busLine">Bus line</label>
                <input type="text" name="busLine" id="busLine" class="mt-1 block w-full px-3 py-2 bg-white border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-blue-500 focus:border-blue-500">
            </div>
            <div class="flex justify-end">
                <button type="submit" class="inline-flex items-center px-4 py-2 bg-blue-500 border border-transparent rounded-md font-semibold text-xs text-white uppercase tracking-widest hover:bg-blue-700 active:bg-blue-900 focus:outline-none focus:border-blue-900 focus:ring focus:ring-blue-300 disabled:opacity-25 transition">
                    Submit
                </button>
            </div>
        </form>
        `;
                // 显示模态框
                modal.classList.remove('hidden');
            });
        });

        // 增加按钮点击事件
        addButtons.forEach(button => {
            button.addEventListener('click', function () {
                modalContent.innerHTML = `
            <h2 class="text-lg font-bold mb-4">Add Bus</h2>
        <form id="addBusForm" class="space-y-4" action="../Admin/bus_manage.php" method="post">
            <input type="hidden" name="formType" value="addBusForm">
            <div>
                <label class="block text-sm font-medium text-gray-700" for="account">Bus Service Number</label>
                <input type="text" name="busService" id="busService" class="mt-1 block w-full px-3 py-2 bg-white border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-blue-500 focus:border-blue-500">
            </div>
            <div>
                <label class="block text-sm font-medium text-gray-700" for="tele_Num">Bus line</label>
                <input type="text" name="busLine" id="busLine" class="mt-1 block w-full px-3 py-2 bg-white border border-gray-300 rounded-md shadow-sm focus:outline-none focus:ring-blue-500 focus:border-blue-500">
            </div>
            <div class="flex justify-end">
                <button type="submit" class="inline-flex items-center px-4 py-2 bg-blue-500 border border-transparent rounded-md font-semibold text-xs text-white uppercase tracking-widest hover:bg-blue-700 active:bg-blue-900 focus:outline-none focus:border-blue-900 focus:ring focus:ring-blue-300 disabled:opacity-25 transition">
                    Submit
                </button>
            </div>
        </form>
        `;
                modal.classList.remove('hidden');
            });
        });

        // 点击模态框外区域关闭模态框
        modal.addEventListener('click', function (e) {
            if (e.target === modal) {
                modal.classList.add('hidden');
            }
        });
    });
</script>
