<?php
include_once '../Logic/config.php';
// 准备SQL查询
$stmt = DB->prepare("SELECT * FROM user WHERE user_Type = ?");
$stmt->execute(['user']);
$users = $stmt->fetchAll(PDO::FETCH_ASSOC);

function editUserInfo($data, $userId)
{
    // 初始化部分
    $sql = "UPDATE user SET ";
    $params = [];
    $updates = [];
    // 根据$data中的非空字段构建更新语句
    foreach ($data as $key => $value) {
        if (!empty($value) || $value === '0') { // 检查非空，允许“0”作为有效值
            $updates[] = "$key = ?";
            $params[] = $value;
        }
    }

    // 如果没有任何字段需要更新，直接返回
    if (empty($updates)) {
        return false;
    }

    $sql .= implode(', ', $updates);
    $sql .= " WHERE id = ?";
    $params[] = $userId;

    // 执行更新
    $stmt = DB->prepare($sql);
    return $stmt->execute($params);
}

function addUser($studentId, $account, $password, $teleNumber, $email)
{
    // 查询学生数据库
    $stmt = DB->prepare("SELECT * FROM student");
    $stmt->execute();
    $students = $stmt->fetchAll(PDO::FETCH_ASSOC);
    $found = false;

    $stmt = DB->prepare("SELECT * FROM user WHERE id = ?");
    $stmt->execute([$studentId]);
    $existingUser = $stmt->fetch(PDO::FETCH_ASSOC);
    if ($existingUser) {
        // 学生已存在，提示用户已注册
        echo "<script>alert('Already has this user!');</script>";
        echo "<script>window.location.href = window.location.href;</script>";
        exit;
    }

    foreach ($students as $student) {
        if ((string)$student['id'] == $studentId) {
            //在数据库中创建新用户
            $sql = "INSERT INTO user(user_Name, user_Major, enrollment_Year, email, account, password, tele_Num, id, user_Type) VALUES (?, ?, ?, ?, ?, ?, ?, ?, 'user')";
            $stmt = DB->prepare($sql);
            $found = true;
            return $stmt->execute([$student['student_name'], $student['major'], $student['enrollment_year'], $email, $account, $password, $teleNumber, $studentId]);
            break;
        }
    }
    if (!$found) {
        echo "<script>
                alert('Not in the Student list!');
                window.location.href = window.location.href; // 刷新本页面
              </script>";
        exit;
    }
}

function deleteUser($studentId)
{
    $sql = "DELETE FROM user WHERE id = ?";
    $stmt = DB->prepare($sql);
    return $stmt->execute([$studentId]);
}


if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // 检查是否存在userId参数
    $userID = isset($_POST['userId']) ? $_POST['userId'] : null;

    // 处理表单提交的数据
    if ($_POST["formType"] == "editInfoForm") {
        $userId = $_POST['id'];
        $data = [
            'account' => $_POST['account'],
            'password' => $_POST['password'],
            'tele_Num' => $_POST['tele_Num'],
            'email' => $_POST['email'],
            // 任何其他字段...
        ];

        editUserInfo($data, $userId);
        echo "<script>window.location.href ='../Admin/user_manage.php';</script>";
    } elseif ($_POST["formType"] == "addUserForm") {
        // 接收表单数据
        $studentId = $_POST['studentId'];
        $account = $_POST['account'];
        $password = $_POST['password'];
        $teleNumber = $_POST['tele_Num'];
        $email = $_POST['email'];

        addUser($studentId, $account, $password, $teleNumber, $email);
        echo "<script>window.location.href ='../Admin/user_manage.php';</script>";
    } elseif ($_POST["formType"] == "delUserForm") {
        $userId = $_POST['userId'];

        deleteUser($userId);
        echo "<script>window.location.href ='../Admin/user_manage.php';</script>";
    }

}
?>


<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>User Management</title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.3/css/all.min.css">
</head>
<body class="bg-gray-100">
<div class="container mx-auto p-4">
    <table class="min-w-full max-w-4xl mx-auto border-collapse">
        <thead class="bg-gray-800 text-white">
        <tr class="border-b">
            <th class="px-4 py-2 text-left rounded-tl-lg">User Name</th>
            <th class="px-4 py-2 text-left">Major</th>
            <th class="px-4 py-2 text-left">Enrollment Year</th>
            <th class="px-4 py-2 text-left">Account</th>
            <th class="px-4 py-2 text-left">Password</th>
            <th class="px-4 py-2 text-left">Student ID</th>
            <th class="px-4 py-2 text-left">Telephone Number</th>
            <th class="px-4 py-2 text-left">Email</th>
            <th class="px-4 py-2 text-left rounded-tr-lg">Operations</th>
        </tr>
        </thead>
        <tbody>
        <?php foreach ($users as $user) { ?>
            <tr class="border-b">
                <td class="px-4 py-2"><?php echo htmlspecialchars($user['user_Name']) ?></td>
                <td class="px-4 py-2"><?php echo htmlspecialchars($user['user_Major']) ?></td>
                <td class="px-4 py-2"><?php echo htmlspecialchars($user['enrollment_Year']) ?></td>
                <td class="px-4 py-2"><?php echo htmlspecialchars($user['account']) ?></td>
                <td class="px-4 py-2"><?php echo htmlspecialchars($user['password']) ?></td>
                <td class="px-4 py-2"><?php echo htmlspecialchars($user['id']) ?></td>
                <td class="px-4 py-2"><?php echo htmlspecialchars($user['tele_Num']) ?></td>
                <td class="px-4 py-2"><?php echo htmlspecialchars($user['email']) ?></td>
                <td class="px-4 py-2 text-center">
                    <!-- 编辑按钮 -->
                    <button class="edit-btn text-blue-500 hover:text-blue-700 mx-2"
                            data-id="<?php echo htmlspecialchars($user['id']) ?>"
                            data-type="edit">
                        <i class="fas fa-edit"></i>
                    </button>
                    <!-- 删除按钮 -->
                    <form action="../Admin/user_manage.php" method="post" class="inline-block">
                        <input type="hidden" name="userId"
                               value="<?php echo htmlspecialchars($user['id']) ?>">
                        <input type="hidden" name="formType" value="delUserForm">
                        <button type="submit" class="text-red-500 hover:text-red-700 mx-2">
                            <i class="fas fa-trash-alt"></i>
                        </button>
                    </form>
                </td>
            </tr>
        <?php } ?>
        <!-- 增加按钮 -->
        <tr class="border-b">
            <td colspan="6" class="px-4 py-2 text-center">
                <button class="add-btn text-green-500 hover:text-green-700 mx-2" data-type="add">
                    <i class="fas fa-plus-square"></i>
                </button>
            </td>
        </tr>
        </tbody>
    </table>
</div>

<!-- 弹出框，初始时隐藏 -->
<div id="modal"
     class="hidden fixed inset-0 bg-gray-600 bg-opacity-50 overflow-y-auto h-full w-full flex items-center justify-center">
    <div class="bg-white p-8 rounded-lg shadow-lg max-w-lg w-full mx-auto" id="modal-content">
        <!-- 弹出框内容 -->
    </div>
</div>

<div class="fixed bottom-0 right-0 p-4">
    <button onclick="window.location.reload()"
            class="px-4 py-2 bg-gray-800 text-white rounded-md shadow-md hover:bg-gray-900 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-opacity-50">
        <i class="fas fa-sync-alt mr-2"></i>
    </button>
</div>

<script src="../Logic/user_manage.js"></script>
</body>
</html>
