let map;
let schoolOverlay;

function loadGoogleMapsAPI() {
    // 创建一个script元素
    var script = document.createElement('script');
    script.type = 'text/javascript';
    script.src = 'https://maps.googleapis.com/maps/api/js?key=AIzaSyDK6Mv_YWM0M2iOFuqjB2YWQrYPbKvpGJU&libraries=places&callback=initMap';
    script.async = true;
    script.defer = true;
    document.body.appendChild(script);
}

loadGoogleMapsAPI();

function initMap() {
    const schoolLatLng = {lat: 51.50070917690589, lng: -2.5474203036155645}; // 更换为你学校的实际经纬度
    map = new google.maps.Map(document.getElementById('map'), {
        zoom: 18,
        center: schoolLatLng,
        restriction: {
            latLngBounds: {
                north: 51.545302312719976, // 实际的北边界纬度
                south: 51.39364543097778, // 实际的南边界纬度
                east: -2.452456079577689, // 实际的东边界经度
                west: -2.7293783311528226 // 实际的西边界经度
            },
            strictBounds: true, // 当设置为true时，用户不能滚动到限制之外
        }
    });

    //获取用户位置
    if (navigator.geolocation) {
        navigator.geolocation.watchPosition((position) => {
            const userLocation = {
                lat: position.coords.latitude,
                lng: position.coords.longitude
            };
            const userMarker = new google.maps.Marker({
                position: userLocation,
                map: map,
                title: 'Your Location',
                icon: {
                    url: 'http://localhost/zhushou/Data/woman.png', // 用户位置的自定义图标
                    scaledSize: new google.maps.Size(30, 30)
                }
            });
            map.setCenter(userLocation);
        }, () => {
            handleLocationError(true, map.getCenter());
        }, {
            enableHighAccuracy: true, // 启用高精度模式
            timeout: 10000, // 最长等待时间
            maximumAge: 0 // 不接受缓存的位置
        });
    } else {
        handleLocationError(false, map.getCenter());
    }


    //以下代码为了搜索地点
    const input = document.getElementById('place-search');
    const searchBox = new google.maps.places.SearchBox(input);

    map.addListener('bounds_changed', function () {
        searchBox.setBounds(map.getBounds());
    });

    let markers = [];
    // 监听搜索框的结果
    searchBox.addListener('places_changed', function () {
        const places = searchBox.getPlaces();

        if (places.length == 0) {
            return;
        }

        // 清除旧的标记
        markers.forEach(marker => marker.setMap(null));
        markers = [];

        // 为每个地点创建一个新标记
        const bounds = new google.maps.LatLngBounds();
        places.forEach(place => {
            if (!place.geometry || !place.geometry.location) {
                console.log("Returned place contains no geometry");
                return;
            }

            markers.push(new google.maps.Marker({
                map: map,
                title: place.name,
                position: place.geometry.location,
                icon: {
                    url: 'location-pin.png',
                    scaledSize: new google.maps.Size(40, 40) // 可选：调整图标大小
                }
            }));

            if (place.geometry.viewport) {
                // 如果地点具有视口，则使用该视口
                bounds.union(place.geometry.viewport);
            } else {
                bounds.extend(place.geometry.location);
            }
        });
        map.fitBounds(bounds);
    });

    //查找特定地点
    document.querySelectorAll('.place-btn').forEach(button => {
        button.addEventListener('click', function () {
            const name = this.getAttribute('data-name');
            const lat = parseFloat(this.dataset.lat);
            const lng = parseFloat(this.dataset.lng);

            const openTime = this.getAttribute('data-opentime');
            const description = this.getAttribute('data-description');
            const address = this.getAttribute('data-address');

            // 清除现有的标记
            markers.forEach(marker => marker.setMap(null));
            markers = [];

            const location = new google.maps.LatLng(lat, lng);
            const marker = new google.maps.Marker({
                position: location,
                map: map,
                title: name
            });
            markers.push(marker);

            // 更新地图中心
            map.setCenter(location);

            // 更新地点信息
            const infoContent = '<h3>' + name + '</h3><br>' + '<h3>Opening Time:</h3><br>' + '<p>' + openTime + '</p><br>' + '<h3>Details:</h3>' + '<p>' + description + '</p>' + '<h3>Address:</h3>' + '<p>' + address + '</p>';
            document.getElementById('place-info').innerHTML = infoContent;
        });
    });

}







