let map;
let schoolOverlay;

function loadGoogleMapsAPI() {
    // 创建一个script元素
    var script = document.createElement('script');
    script.type = 'text/javascript';
    script.src = 'https://maps.googleapis.com/maps/api/js?key=AIzaSyDK6Mv_YWM0M2iOFuqjB2YWQrYPbKvpGJU&libraries=places&callback=initMap';
    script.async = true;
    script.defer = true;
    document.body.appendChild(script);
}

loadGoogleMapsAPI();

function initMap() {
    const schoolLatLng = { lat: 51.50070917690589, lng: -2.5474203036155645 }; // 更换为你学校的实际经纬度
    map = new google.maps.Map(document.getElementById('map'), {
        zoom: 18,
        center: schoolLatLng,
        restriction: {
            latLngBounds: {
                north: 51.504557519157395, // 调整为实际的北边界纬度
                south: 51.49706093330638, // 调整为实际的南边界纬度
                east: -2.5444594597562413, // 调整为实际的东边界经度
                west: -2.5563162082013267  // 调整为实际的西边界经度
            },
            strictBounds: true, // 当设置为true时，用户不能滚动到限制之外
        }
    });

    // 建筑物信息数组
    const buildings = [
        {name: 'P block', position: {lat: 51.50125112962876, lng: -2.549300950111658}},
        {name: 'Q block', position: {lat: 51.50185766147944, lng: -2.5486964869127413}},
        {name: 'X block', position: {lat: 51.50073813856449, lng: -2.54998663237885}},
        {name: 'U block', position: {lat: 51.50084734665425, lng: -2.551211477829162}},
        {name: 'W block', position: {lat: 51.50078828463828, lng: -2.552794130590896}},
        {name: 'T block', position: {lat: 51.50154083985567, lng: -2.5520814053408927}},
        {name: 'Z block', position: {lat: 51.50008626296237, lng: -2.5500875789162394}},
        {name: 'R block', position: {lat: 51.50243097309301, lng: -2.5486079971964033}},
        {name: 'N block', position: {lat: 51.50085973838492, lng: -2.5473954938364756}},
        {name: 'E block', position: {lat: 51.50020855741843, lng: -2.548012401892443}},
        {name: 'D block', position: {lat: 51.49994474299674, lng: -2.548876073161373}},
        {name: 'F block', position: {lat: 51.500230158958395, lng: -2.547470693791909}},
        {name: 'M block', position: {lat: 51.50039663176812, lng: -2.547004128184547}},
        {name: 'G block', position: {lat: 51.50016286126813, lng: -2.546875158833607}},
        {name: 'H block', position: {lat: 51.49989130817341, lng: -2.5469434367255173}},
        {name: 'J block', position: {lat: 51.49975907303713, lng: -2.5464389389686235}},
        {name: 'K block', position: {lat: 51.49970240071482, lng: -2.5470041281878184}},
        {name: 'L block', position: {lat: 51.499700039360654, lng: -2.5474327616356875}},
        {name: 'A block', position: {lat: 51.49924901962131, lng: -2.5475086259537867}},
        {name: 'B block', position: {lat: 51.498972738305554, lng: -2.548100367685757}},
        {name: 'C block', position: {lat: 51.499411548821115, lng: -2.5482445099049857}},
        {name: 'S block', position: {lat: 51.49782582113284, lng: -2.548225615718025}},
    ];

    // 为每个建筑物创建一个标记
    buildings.forEach(building => {
        const marker = new google.maps.Marker({
            position: building.position,
            map: map,
            label: {
                text: building.name, // 显示建筑物的名字
                color: "black", // 标签文字颜色
                fontSize: "12px", // 标签文字大小
                fontWeight: "bold" // 标签文字加粗
            }
        });
    });

    //获取用户位置
    if (navigator.geolocation) {
        navigator.geolocation.watchPosition((position) => {
            const userLocation = {
                lat: position.coords.latitude,
                lng: position.coords.longitude
            };
            const userMarker = new google.maps.Marker({
                position: userLocation,
                map: map,
                title: 'Your Location',
                icon: {
                    url: 'http://localhost/zhushou/Data/woman.png', // 用户位置的自定义图标
                    scaledSize: new google.maps.Size(20, 20)
                }
            });
            map.setCenter(userLocation);
        }, () => {
            handleLocationError(true, map.getCenter());
        }, {
            enableHighAccuracy: true, // 启用高精度模式
            timeout: 10000, // 最长等待时间
            maximumAge: 0 // 不接受缓存的位置
        });
    } else {
        handleLocationError(false, map.getCenter());
    }


    //以下代码为了搜索地点
    const input = document.getElementById('place-search');
    const searchBox = new google.maps.places.SearchBox(input);

    map.addListener('bounds_changed', function() {
        searchBox.setBounds(map.getBounds());
    });

    let markers = [];
    // 监听搜索框的结果
    searchBox.addListener('places_changed', function() {
        const places = searchBox.getPlaces();

        if (places.length == 0) {
            return;
        }

        // 清除旧的标记
        markers.forEach(marker => marker.setMap(null));
        markers = [];

        // 为每个地点创建一个新标记
        const bounds = new google.maps.LatLngBounds();
        places.forEach(place => {
            if (!place.geometry || !place.geometry.location) {
                console.log("Returned place contains no geometry");
                return;
            }

            markers.push(new google.maps.Marker({
                map: map,
                title: place.name,
                position: place.geometry.location,
                icon: {
                    url: 'http://localhost/zhushou/Data/location-pin.png',
                    scaledSize: new google.maps.Size(40, 40) // 可选：调整图标大小
                }
            }));

            if (place.geometry.viewport) {
                // 如果地点具有视口，则使用该视口
                bounds.union(place.geometry.viewport);
            } else {
                bounds.extend(place.geometry.location);
            }
        });
        map.fitBounds(bounds);
    });

    //查找特定地点
    document.querySelectorAll('.place-btn').forEach(button => {
        button.addEventListener('click', function() {
            const name = this.getAttribute('data-name');
            const lat = parseFloat(this.dataset.lat);
            const lng = parseFloat(this.dataset.lng);

            const openTime = this.getAttribute('data-opentime');
            const description = this.getAttribute('data-description');

            // 清除现有的标记
            markers.forEach(marker => marker.setMap(null));
            markers = [];

            const location = new google.maps.LatLng(lat, lng);
            const marker = new google.maps.Marker({
                position: location,
                map: map,
                title: name
            });
            markers.push(marker);

            // 更新地图中心
            map.setCenter(location);

            // 更新地点信息
            const infoContent = '<h3>' + name + '</h3><br>' + '<h3>Opening Time:</h3><br>' + '<p>' + openTime + '</p><br>' + '<h3>Details:</h3>' + '<p>' + description + '</p>';;
            document.getElementById('place-info').innerHTML = infoContent;
        });
    });

}

