<?php
session_start(); // 开启会话
require_once '../Logic/config.php';
require_once "../Logic/ChatbotConfig.php"; // 引入API文件

function getPredefinedResponse($userInput) {
    $response = false;

    // 查询数据库获取所有预定义的回答
    $stmt = DB->prepare("SELECT * FROM responses");
    $stmt->execute();
    $responses = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 遍历预定义的回答
    foreach ($responses as $predefinedResponse) {
        $pattern = "/" . $predefinedResponse['pattern'] . "/i"; // 构造正则表达式
        // 检查是否匹配
        if (preg_match($pattern, $userInput)) {
            $response = $predefinedResponse['response'];
            break; // 找到匹配后退出循环
        }
    }

    return $response;
}

if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // 获取用户输入
    $userInput = $_POST['userInput'];
    // 尝试从数据库中找到预定义的回答
    $response = getPredefinedResponse($userInput);

    // 如果没有找到预定义的回答，调用API函数
    if (!$response) {
        $response = gpt35Api([['role' => 'user', 'content' => $userInput]]);
    }

    // 把用户输入和响应追加到会话历史中
    if (!isset($_SESSION['chat_history'])) {
        $_SESSION['chat_history'] = [];
    }
    $_SESSION['chat_history'][] = ['user' => $userInput, 'response' => $response];
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Chat Interface</title>
    <link rel="stylesheet" href="../css/chatbotpage.css">
</head>
<body>
<div id="chat-container">
    <div id="chat-history">
        <?php if (!empty($_SESSION['chat_history'])): ?>
            <?php foreach ($_SESSION['chat_history'] as $chat): ?>
                <div class="user"><?php echo htmlspecialchars($chat['user']); ?></div>
                <div class="bot"><?php echo htmlspecialchars($chat['response']); ?></div>
            <?php endforeach; ?>
        <?php endif; ?>
    </div>
    <form action="chatbotpage.php" method="post">
        <input type="text" name="userInput" required autofocus>
        <button type="submit">Send</button>
    </form>
</div>

</body>

<script>
    window.onload = function() {
        var chatHistory = document.getElementById('chat-history');
        chatHistory.scrollTop = chatHistory.scrollHeight;
    };
</script>


</html>
